@@ -479,11 +479,25 @@ create_smb_uri_string (const char *server,
   GString *uri;
 
   uri = g_string_new ("smb://");
-  g_string_append_encoded (uri, server, NULL);
+  if (server == NULL)
+    return uri;
+
+  /* IPv6 server includes brackets in GMountSpec, smbclient doesn't */
+  if (server[0] == '[')
+    {
+      g_string_append_encoded (uri, server + 1, NULL);
+      g_string_truncate (uri, uri->len - 3);
+    }
+  else
+    g_string_append_encoded (uri, server, NULL);
+
   if (port != -1)
     g_string_append_printf (uri, ":%d", port);
   g_string_append_c (uri, '/');
-  g_string_append_encoded (uri, share, NULL);
+
+  if (share != NULL)
+    g_string_append_encoded (uri, share, NULL);
+
   if (path != NULL)
     {
       if (*path != '/')
@@ -498,7 +512,7 @@ create_smb_uri_string (const char *server,
   return uri;
 }
 
-static char *
+char *
 create_smb_uri (const char *server,
 		int port,
 		const char *share,
