@@ -13,9 +13,8 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Public License along with this library; if not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Author: Tomas Bzatek <tbzatek@redhat.com>
  */
@@ -31,6 +30,13 @@
 #include <glib/gi18n.h>
 #include "gvfsjobprogress.h"
 
+#define RATE_LIMIT_TIME 100000
+
+struct _GVfsJobProgressPrivate
+{
+  gint64 last_time;
+};
+
 G_DEFINE_TYPE (GVfsJobProgress, g_vfs_job_progress, G_VFS_TYPE_JOB_DBUS)
 
 static void
@@ -51,6 +57,8 @@ static void
 g_vfs_job_progress_class_init (GVfsJobProgressClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
+
+  g_type_class_add_private (klass, sizeof (GVfsJobProgressPrivate));
   
   gobject_class->finalize = g_vfs_job_progress_finalize;
 }
@@ -58,6 +66,7 @@ g_vfs_job_progress_class_init (GVfsJobProgressClass *klass)
 static void
 g_vfs_job_progress_init (GVfsJobProgress *job)
 {
+  job->priv = G_TYPE_INSTANCE_GET_PRIVATE (job, G_VFS_TYPE_JOB_PROGRESS, GVfsJobProgressPrivate);
 }
 
 void
@@ -67,6 +76,12 @@ g_vfs_job_progress_callback (goffset current_num_bytes,
 {
   GVfsJobProgress *job = G_VFS_JOB_PROGRESS (user_data);
   GVfsJobDBus *dbus_job = G_VFS_JOB_DBUS (job);
+  gint64 current_time = g_get_monotonic_time ();
+
+  if (current_time - job->priv->last_time < RATE_LIMIT_TIME &&
+      current_num_bytes != total_num_bytes)
+    return;
+  job->priv->last_time = current_time;
 
   g_debug ("g_vfs_job_progress_callback %" G_GOFFSET_FORMAT "/%" G_GOFFSET_FORMAT "\n", current_num_bytes, total_num_bytes);
 
